<?php
/* ======================================================
 # JLogs for Joomla! - v1.0.2 (free version)
 # -------------------------------------------------------
 # For Joomla! CMS (v3.x)
 # Author: Web357 (Yiannis Christodoulou)
 # Copyright (©) 2014-2023 Web357. All rights reserved.
 # License: GNU/GPLv3, http://www.gnu.org/licenses/gpl-3.0.html
 # Website: https:/www.web357.com
 # Demo: https://www.web357.com/product/jlogs-joomla-component
 # Support: support@web357.com
 # Last modified: Friday 05 April 2024, 12:37:11 AM
 ========================================================= */

defined('_JEXEC') or die;

use Joomla\CMS\Factory;
use Joomla\CMS\Filesystem\Folder;
use Joomla\CMS\HTML\HTMLHelper;
use Joomla\CMS\Component\ComponentHelper;

/**
 * Methods supporting a list of Jlogs records.
 *
 * @since  1.6
 */
class JlogsModelJlogs extends \Joomla\CMS\MVC\Model\ListModel
{
	/**
	 * Get the log files
	 *
	 * @return void
	 */
	public function getLogFiles()
	{
		// Get Paremeters from the configuration file
		$config = Factory::getConfig();
		$log_path = $config->get('log_path');
		$log_files = Folder::files($log_path, '.', true, true, ['index.html']);

		// Get component params
		$params = ComponentHelper::getComponent('com_jlogs')->getParams();
		$last_modified_datetime_date_format = $params->get('last_modified_datetime_date_format', 'Y-m-d H:i:s T');
		$sorting = $params->get('sorting', 'last_modified_desc');

		$jlog_files_arr = [];
		foreach ($log_files as $log_file)
		{
			// Get the file info
			$file_name = basename($log_file);
			$file_size_numeric = filesize($log_file);
			$file_size = JlogsHelper::formatSizeUnits(filesize($log_file));
			$file_last_modified = HTMLHelper::_('date', filemtime($log_file), $last_modified_datetime_date_format);
			$file_last_modified_v = HTMLHelper::_('date', filemtime($log_file), 'Y-m-d H:i:s');

			$jlog_files_arr[] = [
				'file_full_path' => $log_file,
				'file_name' => $file_name,
				'file_size_numeric' => $file_size_numeric,
				'file_size' => $file_size,
				'file_last_modified' => $file_last_modified,
				'file_last_modified_v' => $file_last_modified_v,
			];
		}

		// Sort array params
		switch ($sorting) 
		{
			case 'last_modified_asc':
				$sorting_column_key = 'file_last_modified_v';
				$sort_order = SORT_ASC;
				break;
			case 'last_modified_desc':
				$sorting_column_key = 'file_last_modified_v';
				$sort_order = SORT_DESC;
				break;
			case 'filesize_asc':
				$sorting_column_key = 'file_size_numeric';
				$sort_order = SORT_ASC;
				break;
			case 'filesize_desc':
				$sorting_column_key = 'file_size_numeric';
				$sort_order = SORT_DESC;
				break;
			case 'filename_asc':
				$sorting_column_key = 'file_name';
				$sort_order = SORT_ASC;
				break;
			case 'filename_desc':
				$sorting_column_key = 'file_name';
				$sort_order = SORT_DESC;
				break;
			default:
				$sorting_column_key = 'file_last_modified_v';
				$sort_order = SORT_DESC;
				break;
		}

		// Sort array by a parameter
		$keys = array_column($jlog_files_arr, $sorting_column_key);
		array_multisort($keys, $sort_order, $jlog_files_arr);

		// Convert php array to an object array
		if (!empty($jlog_files_arr))
		{
			return json_decode(json_encode($jlog_files_arr), FALSE);
		}

		return;
	}
}
