<?php
/* ======================================================
 # JLogs for Joomla! - v1.0.2 (free version)
 # -------------------------------------------------------
 # For Joomla! CMS (v3.x)
 # Author: Web357 (Yiannis Christodoulou)
 # Copyright (©) 2014-2023 Web357. All rights reserved.
 # License: GNU/GPLv3, http://www.gnu.org/licenses/gpl-3.0.html
 # Website: https:/www.web357.com
 # Demo: https://www.web357.com/product/jlogs-joomla-component
 # Support: support@web357.com
 # Last modified: Friday 05 April 2024, 12:37:11 AM
 ========================================================= */

// No direct access
defined('_JEXEC') or die;

jimport('joomla.application.component.view');

use \Joomla\CMS\Language\Text;
use \Joomla\CMS\Factory;
use \Joomla\CMS\Uri\Uri;
use \Joomla\CMS\Toolbar\ToolbarHelper;
use \Joomla\CMS\Toolbar\Toolbar;
use \Joomla\CMS\HTML\HTMLHelper;
use \Joomla\CMS\Router\Route;
use \Joomla\CMS\Filesystem\File;
use \Joomla\CMS\Component\ComponentHelper;

/**
 * View class for a list of Jlogs.
 *
 * @since  1.6
 */
class JlogsViewJlogs extends \Joomla\CMS\MVC\View\HtmlView
{
	/**
	 * Display the view
	 *
	 * @param   string  $tpl  Template name
	 *
	 * @return void
	 *
	 * @throws Exception
	 */
	public function display($tpl = null)
	{
		// Get component params
		$params = ComponentHelper::getComponent('com_jlogs')->getParams();
		$last_modified_datetime_date_format = $params->get('last_modified_datetime_date_format', 'Y-m-d H:i:s T');
		$this->show_file_size_col = $params->get('show_file_size_col', '1');
		$this->show_file_last_modified_col = $params->get('show_file_last_modified_col', '1');
		$this->show_empty_file_contents_col = $params->get('show_empty_file_contents_col', '1');
		$this->show_delete_file_col = $params->get('show_delete_file_col', '1');
		$this->show_the_debug_mode_message = $params->get('show_the_debug_mode_message', '1');
		
		// Get Paremeters from the configuration file
		$config = Factory::getConfig();
		$this->debug = $config->get('debug', 0);

		// CSS
		$document = Factory::getDocument();
		$document->addStyleSheet(Uri::root() . 'administrator/components/com_jlogs/assets/css/jlogs.css');

		// get the log files
		$this->jlog_files = $this->get('LogFiles');

		$this->link_to_pro = '<a href="https://www.web357.com/product/jlogs-extension-for-joomla?utm_source=CLIENT&utm_medium=CLIENT-JLOGS-ProLink-web357&utm_content=CLIENT-JLOGS-ProLink&utm_campaign=JLOGS_radiofelement_free_vs_pro" target="_blank">PRO</a>';

		// Get vars from URL
		$get_file_full_path = Factory::getApplication()->input->get('file', '', 'STRING');

		$this->file_name = '';
		$this->file_size = '';
		$this->file_last_modified = '';
		$this->file_contents = '';
		$this->file_full_path = $get_file_full_path;
		if (File::exists($get_file_full_path))
		{
			$this->file_name = basename($get_file_full_path);
			$this->file_size = JlogsHelper::formatSizeUnits(filesize($get_file_full_path));
			$this->file_last_modified = HTMLHelper::_('date', filemtime($get_file_full_path), $last_modified_datetime_date_format);
			
			// file contents
			$file_contents = file_get_contents($get_file_full_path);
			$file_contents = preg_replace('/\sALL\s/', '<span class="jlog-priority jlog-priority-all">ALL</span>', $file_contents);
			$file_contents = preg_replace('/\sEMERGENCY\s/', '<span class="jlog-priority jlog-priority-emergency">EMERGENCY</span>', $file_contents);
			$file_contents = preg_replace('/\sALERT\s/', '<span class="jlog-priority jlog-priority-alert">ALERT</span>', $file_contents);
			$file_contents = preg_replace('/\sCRITICAL\s/', '<span class="jlog-priority jlog-priority-critical">CRITICAL</span>', $file_contents);
			$file_contents = preg_replace('/\sERROR\s/', '<span class="jlog-priority jlog-priority-error">ERROR</span>', $file_contents);
			$file_contents = preg_replace('/\sWARNING\s/', '<span class="jlog-priority jlog-priority-warning">WARNING</span>', $file_contents);
			$file_contents = preg_replace('/\sNOTICE\s/', '<span class="jlog-priority jlog-priority-notice">NOTICE</span>', $file_contents);
			$file_contents = preg_replace('/\sINFO\s/', '<span class="jlog-priority jlog-priority-info">INFO</span>', $file_contents);
			$file_contents = preg_replace('/\sDEBUG\s/', '<span class="jlog-priority jlog-priority-debug">DEBUG</span>', $file_contents);
			
			$this->file_contents =  '';
			foreach(explode("\n",$file_contents) as $line)
			{
				if (!empty($line))
				{
					$this->file_contents .= '<div class="jlog-file-contents-line-separator">'.$line.'</div>';
				}
			}

		}

		$this->addToolbar();

		if ($this->getLayout() == 'viewlogfile')
		{
			$this->setLayout('viewlogfilecontents');
		}

		parent::display($tpl);
	}

	/**
	 * Add the page title and toolbar.
	 *
	 * @return void
	 *
	 * @since    1.6
	 */
	protected function addToolbar()
	{
		$canDo = JlogsHelper::getActions();

		// Get the toolbar object instance
		$toolbar = Toolbar::getInstance('toolbar');

		JToolBarHelper::title(Text::_('COM_JLOGS_COMPONENT_TITLE'), 'jlogs.png');

		// Home
		$link = HTMLHelper::_(
			'link',
			Route::_('index.php?option=com_jlogs'),
			'<span class="icon-home"></span> '.Text::_('Home '),
			[
				'class' => 'btn btn-small',
			]
		);
		ToolBar::getInstance('toolbar')->appendButton('Custom', $link);

		// Refresh
		if ($this->getLayout() == 'viewlogfile')
		{
			$link = HTMLHelper::_(
				'link',
				Route::_('index.php?option=com_jlogs&layout=viewlogfile&file='.$this->file_full_path),
				'<span class="icon-refresh"></span> '.Text::_('Reload'),
				[
					'title' => Text::_('Reload'),
					'class' => 'btn btn-small ms-3',
				]
			);
			ToolBar::getInstance('toolbar')->appendButton('Custom', $link);
		}

		// Empty the file contents
		if ($canDo->get('core.admin') && $canDo->get('core.clear') && !empty($this->jlog_files) && $this->getLayout() == 'default')
		{
			
			$link = HTMLHelper::_(
				'link',
				Route::_('index.php?option=com_jlogs'),
				'<span class="icon-trash"></span> '.Text::_('Empty the content of ALL log files'),
				[
					'class' => 'btn btn-small ms-3',
			 		'onclick'	=> 'alert(\''.Text::_('This feature is available only in PRO version.').'\');return false;'
			]
			);

			ToolBar::getInstance('toolbar')->appendButton('Custom', $link);
		}

		// Delete the files
		if ($canDo->get('core.admin') && $canDo->get('core.delete') && !empty($this->jlog_files) && $this->getLayout() == 'default')
		{
			
			$link = HTMLHelper::_(
				'link',
				Route::_('index.php?option=com_jlogs'),
				'<span class="icon-delete"></span> '.Text::_('Delete ALL log files'),
				[
					'class' => 'btn btn-small',
					'onclick'	=> 'alert(\''.Text::_('This feature is available only in PRO version.').'\');return false;'
				]
			);

			ToolBar::getInstance('toolbar')->appendButton('Custom', $link);
		}

		// Empty the file contents of a specific file
		if ($canDo->get('core.admin') && $canDo->get('core.clear') && !empty($this->jlog_files) && $this->getLayout() == 'viewlogfile')
		{
			
			$link = HTMLHelper::_(
				'link',
				Route::_('index.php?option=com_jlogs'),
				'<span class="icon-trash"></span> '.Text::_('Empty the content of this file'),
				[
					'title' => Text::_('Empty file contents'),
					'class' => 'btn btn-small ms-3',
					'onclick'	=> 'alert(\''.Text::_('This feature is available only in PRO version.').'\');return false;'
				]
			);

			ToolBar::getInstance('toolbar')->appendButton('Custom', $link);
		}

		// Delete a file
		if ($canDo->get('core.admin') && $canDo->get('core.delete') && !empty($this->jlog_files) && $this->getLayout() == 'viewlogfile')
		{
			
			$link = HTMLHelper::_(
				'link',
				Route::_('index.php?option=com_jlogs'),
				'<span class="icon-delete"></span> '.Text::_('Delete this file'),
				[
					'title' => Text::_('Delete file'),
					'class' => 'btn btn-small ms-3',
					'onclick'	=> 'alert(\''.Text::_('This feature is available only in PRO version.').'\');return false;'
				]
			);

			ToolBar::getInstance('toolbar')->appendButton('Custom', $link);
		}

		if ($canDo->get('core.admin'))
		{
			ToolBarHelper::preferences('com_jlogs');
		}
	}
}
