<?php
/* ======================================================
 # JLogs for Joomla! - v1.0.2 (free version)
 # -------------------------------------------------------
 # For Joomla! CMS (v4.x)
 # Author: Web357 (Yiannis Christodoulou)
 # Copyright (©) 2014-2023 Web357. All rights reserved.
 # License: GNU/GPLv3, http://www.gnu.org/licenses/gpl-3.0.html
 # Website: https:/www.web357.com
 # Demo: https://www.web357.com/product/jlogs-joomla-component
 # Support: support@web357.com
 # Last modified: Friday 05 April 2024, 12:37:11 AM
 ========================================================= */
 
// No direct access
defined('_JEXEC') or die;

use \Joomla\CMS\Language\Text;
use \Joomla\CMS\Router\Route;
use \Joomla\CMS\HTML\HTMLHelper;

?>
<div class="jlog-container">

<?php 
// If the debug is not enabled display a warning message
if ($this->show_the_debug_mode_message):
    if (!$this->debug): ?>
        <div class="jlogs-debug-is-disabled">
            <span title="<?php echo Text::_('The Joomla! Debug mode is disabled. To enable it, navigate to System > Global Configuration > System > Debug Settings > Debug System > Yes'); ?>">
                <?php echo Text::_('The Joomla! Debug mode is disabled.'); ?>
            </span>
        </div>
    <?php else: ?>
        <div class="jlogs-debug-is-enabled">
            <span title="<?php echo Text::_('The Joomla! Debug mode is enabled. Do not forget to disable it on a live (production) website. To disable it, navigate to System > Global Configuration > System > Debug Settings > Debug System > No'); ?>">
                <?php echo Text::_('The Joomla! Debug mode is enabled.'); ?>
            </span>
        </div>
    <?php 
    endif; 
endif;
?>

<form action="<?php echo Route::_('index.php?option=com_jlogs&view=jlogs'); ?>" method="post" name="adminForm" id="adminForm">
<table class="table table-bordered">
<thead>
<tr>
    <th>#</th>

    <th><?php echo Text::_('File name'); ?></th>
    
    <?php if ($this->show_file_size_col): ?>
    <th><?php echo Text::_('File size'); ?></th>
    <?php endif; ?>

    <?php if ($this->show_file_last_modified_col): ?>
    <th><?php echo Text::_('Last modified'); ?></th>
    <?php endif; ?>

    <?php if ($this->show_empty_file_contents_col): ?>
    <th><?php echo Text::_('Empty file contents'); ?></th>
    <?php endif; ?>

    <?php if ($this->show_delete_file_col): ?>
    <th><?php echo Text::_('Delete file'); ?></th>
    <?php endif; ?>
</tr>
</thead>
<tbody>

<?php
$num = 1;
if (!empty($this->jlog_files)) {
    foreach ($this->jlog_files as $f) { ?>

        <tr>
            <td><?php echo $num; ?></td>
            <td>
                <?php 
                echo HTMLHelper::_(
                    'link',
                    Route::_('index.php?option=com_jlogs&view=jlogs&layout=viewlogfile&file='.urlencode($f->file_full_path)),
                    $f->file_name,
                    [
                        'title' => Text::_('View the contents of the file: ' . $f->file_full_path),
                    ]
                );
                ?>
            </td>

            <?php if ($this->show_file_size_col): ?>
            <td><?php echo $f->file_size; ?></td>
            <?php endif; ?>

            <?php if ($this->show_file_last_modified_col): ?>
            <td><?php echo $f->file_last_modified; ?></td>
            <?php endif; ?>

            <?php if ($this->show_empty_file_contents_col): ?>
            <td>
                <?php if ($f->file_size_numeric === 0): ?>
                    <span><?php echo Text::_('The file is empty'); ?></span>
                <?php else: ?>

                    <?php

                    $pro_only = sprintf(JText::_('Only in %s version'), $this->link_to_pro);
                    echo "<small> " . $pro_only . " </small>";
                    
                    ?>                    
                <?php endif; ?>    
            </td>
            <?php endif; ?>

            <?php if ($this->show_delete_file_col): ?>
            <td>
                <?php

                $pro_only = sprintf(JText::_('Only in %s version'), $this->link_to_pro);
                echo "<small> " . $pro_only . " </small>";
                
                ?>
            </td>
            <?php endif; ?>
        </tr>
        <?php
    $num++;
    }
}
else
{
    ?>
    <tr>
        <td colspan="6">
            <?php echo Text::_('<strong>Currently, there are no any log files!</strong><br>Ensure that the <strong>`Joomla! Debug mode`</strong> is enabled from the Global configuration, and the plugin <strong>`System - Debug`</strong> is enabled.'); ?>
        </td>
    </tr>
    <?php
}
?>
    </tbody>
</table>
<input type="hidden" name="task" value=""/>
<?php echo HTMLHelper::_('form.token'); ?>
</form>

<?php echo \Web357Framework\Functions::showFooter("com_jlogs", JText::_('COM_JLOGS_CLEAN')); ?>
</div>